==> reffi-client-nexaweb-2.1.6-sources.jar: jp/co/fujitsu/reffi/client/nexaweb/listener/ModelProcessListener.java <==
/* 
 * Copyright (c) 2008-2010, FUJITSU LIMITED
 * All rights reserved.
 * 
 *  Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation and/or
 *    other materials provided with the distribution.
 * 
 * 3. Redistributions with modification must carry prominent notices stating that you changed 
 *    the files and the date of any change.
 * 
 * 4. Neither the name of FUJITSU LIMITED nor the names of its contributors may be used
 *    to endorse or promote products derived from this software without specific prior
 *    written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES;LOSS OF USE,DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package jp.co.fujitsu.reffi.client.nexaweb.listener;

import java.util.EventListener;

import jp.co.fujitsu.reffi.client.nexaweb.event.ModelProcessEvent;

/**
 * <p>[概 要] </p>
 * モデルの処理結果を監視するリスナI/Fです。
 * 
 * <p>[詳 細] </p>
 * 
 * 
 * <p>[備 考] </p>
 * 
 * 
 * <p>[環 境] JDK 6.0 Update 11</p>
 * <p>Copyright (c) 2008-2009 FUJITSU Japan All rights reserved.</p>
 * 
 * @author Project Reffi
 */
public interface ModelProcessListener extends EventListener {

	/**
	 * <p>[概 要]</p>
	 * モデル処理が成功した場合にコールされるリスナメソッドです。
	 * 
	 * <p>[詳 細]</p>
	 * モデルから処理正常終了イベントを受信した時にコールされます。<BR>
	 * Object result = evt.getResult();<BR>
	 * で、モデル処理結果オブジェクトを取得出来ます。
	 * 
	 * <p>[備 考]</p>
	 * PublishCoreの成功時やSubscribeCoreの購読中止成功時等、
	 * 正常終了した場合でもモデル処理結果オブジェクトがnullの場合が有ります。
	 * 
	 * @param evt モデル処理が正常終了した情報が入ったイベントオブジェクト
	 */
	public void modelSuccess(ModelProcessEvent evt);

	/**
	 * <p>[概 要]</p>
	 * モデル処理が失敗した場合にコールされるリスナメソッドです。
	 * 
	 * <p>[詳 細]</p>
	 * モデルから処理異常終了イベントを受信した時にコールされます。<BR>
	 * Exception e = evt.getException();<BR>
	 * で、モデル処理中に発生した例外を取得出来ます。
	 * 
	 * <p>[備 考]</p>
	 * 
	 * @param evt モデル処理が異常終了した情報が入ったイベントオブジェクト
	 */
	public void modelFailure(ModelProcessEvent evt);		
}

==> reffi-client-nexaweb-2.1.11-sources.jar: jp/co/fujitsu/reffi/client/nexaweb/listener/ModelProcessListener.java <==
/* 
 * Copyright (c) 2008-2010, FUJITSU LIMITED
 * All rights reserved.
 * 
 *  Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation and/or
 *    other materials provided with the distribution.
 * 
 * 3. Redistributions with modification must carry prominent notices stating that you changed 
 *    the files and the date of any change.
 * 
 * 4. Neither the name of FUJITSU LIMITED nor the names of its contributors may be used
 *    to endorse or promote products derived from this software without specific prior
 *    written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES;LOSS OF USE,DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package jp.co.fujitsu.reffi.client.nexaweb.listener;

import java.util.EventListener;

import jp.co.fujitsu.reffi.client.nexaweb.event.ModelProcessEvent;

/**
 * <p>[概 要] </p>
 * モデルの処理結果を監視するリスナI/Fです。
 * 
 * <p>[詳 細] </p>
 * 
 * 
 * <p>[備 考] </p>
 * 
 * 
 * <p>[環 境] JDK 6.0 Update 11</p>
 * <p>Copyright (c) 2008-2009 FUJITSU Japan All rights reserved.</p>
 * 
 * @author Project Reffi
 */
public interface ModelProcessListener extends EventListener {

	/**
	 * <p>[概 要]</p>
	 * モデル処理が成功した場合にコールされるリスナメソッドです。
	 * 
	 * <p>[詳 細]</p>
	 * モデルから処理正常終了イベントを受信した時にコールされます。<BR>
	 * Object result = evt.getResult();<BR>
	 * で、モデル処理結果オブジェクトを取得出来ます。
	 * 
	 * <p>[備 考]</p>
	 * PublishCoreの成功時やSubscribeCoreの購読中止成功時等、
	 * 正常終了した場合でもモデル処理結果オブジェクトがnullの場合が有ります。
	 * 
	 * @param evt モデル処理が正常終了した情報が入ったイベントオブジェクト
	 */
	public void modelSuccess(ModelProcessEvent evt);

	/**
	 * <p>[概 要]</p>
	 * モデル処理が失敗した場合にコールされるリスナメソッドです。
	 * 
	 * <p>[詳 細]</p>
	 * モデルから処理異常終了イベントを受信した時にコールされます。<BR>
	 * Exception e = evt.getException();<BR>
	 * で、モデル処理中に発生した例外を取得出来ます。
	 * 
	 * <p>[備 考]</p>
	 * 
	 * @param evt モデル処理が異常終了した情報が入ったイベントオブジェクト
	 */
	public void modelFailure(ModelProcessEvent evt);		

	/**
	 * <p>[概 要]</p>
	 * モデル処理が終了した場合にコールされるリスナメソッドです。
	 * 
	 * <p>[詳 細]</p>
	 * モデルから処理終了イベントを受信した時にコールされます。<BR>
	 * 
	 * <p>[備 考]</p>
	 * 
	 * @param evt モデル処理が終了した情報が入ったイベントオブジェクト
	 */
	public void modelFinished(ModelProcessEvent evt);		
}
